#!/bin/env python
# -*- coding: utf8 -*-

from setuptools import setup

setup(
    name='zzz',
    version='0.0.2',
    description='Wait for something to happen',
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
    ],
    keywords='wait sleep time zzz trigger',
    author='David Gay',
    author_email='oddshocks@riseup.net',
    url='https://github.com/oddshocks/zzz',
    license='AGPLv3+',
    include_package_data=True,
    zip_safe=False,
    install_requires=[],
    packages=[],
    entry_points="""
    """,
)
